import java.io.*;
import java.util.*;

public class aerodynamics_rs implements Runnable {
	private static final double eps = 1e-7;
	private static Scanner in;
	private static PrintWriter out;
	
	private class Point {
		public double x, y;
	}
	
	private Point[] p;
	private int[] stack;

	private double convexHullArea(int m) {
		if (m < 3) {
			return 0.0;
		}
		
		int min = 0;
		for (int i = 0; i < m; i++) {
			if (p[i].x + eps < p[min].x || Math.abs(p[i].x - p[min].x) < eps && p[i].y + eps < p[min].y) {
				min = i;
			}
		}
		Point tmp = p[0];
		p[0] = p[min];
		p[min] = tmp;
		
		Arrays.sort(p, 1, m, new Comparator<Point>() {
			@Override
			public int compare(Point p1, Point p2) {
				double dx1 = p1.x - p[0].x;
				double dy1 = p1.y - p[0].y;
				double dx2 = p2.x - p[0].x;
				double dy2 = p2.y - p[0].y;
				double vp = dx1 * dy2 - dx2 * dy1;
				if (Math.abs(vp) > eps) {
					return Double.compare(0, vp);
				}
				double d1 = Math.hypot(dx1, dy1);
				double d2 = Math.hypot(dx2, dy2);
				return Double.compare(d1, d2);
			}
		});
		
		int sp = 2;
		stack[0] = 0;
		stack[1] = 1;
		for (int i = 2; i < m; i++) {
			while (sp > 1) {
				int u = stack[sp - 2];
				int v = stack[sp - 1];
				double dx1 = p[v].x - p[u].x;
				double dy1 = p[v].y - p[u].y;
				double dx2 = p[i].x - p[v].x;
				double dy2 = p[i].y - p[v].y;
				double vp = dx1 * dy2 - dx2 * dy1;
				if (vp > eps) {
					break;
				}
				sp--;
			}
			stack[sp++] = i;
		}
		
		stack[sp] = stack[0];
		double area = 0;
		for (int i = 0; i < sp; i++) {
			double x1 = p[stack[i]].x;
			double y1 = p[stack[i]].y;
			double x2 = p[stack[i + 1]].x;
			double y2 = p[stack[i + 1]].y;
			area += (x1 * y2 - x2 * y1);
		}
		return Math.abs(area) / 2;
	}

	@Override
	public void run() {
		int n = in.nextInt();
		int zmin = in.nextInt();
		int zmax = in.nextInt();
		int[] x = new int[n];
		int[] y = new int[n];
		int[] z = new int[n];
		for (int i = 0; i < n; i++) {
			x[i] = in.nextInt();
			y[i] = in.nextInt();
			z[i] = in.nextInt();
		}
		p = new Point[n * (n - 1) / 2 + n + 10];
		for (int i = 0; i < p.length; i++) {
			p[i] = new Point();
		}
		stack = new int[p.length];
		for (int zz = zmin; zz <= zmax; zz++) {
			out.println(solve(zz, x, y, z));
		}
	}
	
	private double solve(int z0, int[] x, int[] y, int[] z) {
		int n = x.length;
		int m = 0;
		for (int i = 0; i < n; i++) {
			if (z[i] == z0) {
				p[m].x = x[i];
				p[m].y = y[i];
				m++;
			}
		}
		for (int i = 0; i < n; i++) {
			for (int j = i + 1; j < n; j++) {
				if (z[i] == z[j] || z[i] == z0 || z[j] == z0) {
					continue;
				}
				double dx = x[j] - x[i];
				double dy = y[j] - y[i];
				double dz = z[j] - z[i];
				double t = 1.0 * (z0 - z[i]) / dz;
				if (t < -eps || t > 1.0 + eps) {
					continue;
				}
				p[m].x = x[i] + t * dx;
				p[m].y = y[i] + t * dy;
				m++;
			}
		}
		return convexHullArea(m);
	}

	public static void main(String[] args) throws Exception {
		Locale.setDefault(Locale.US);
		String problemName = aerodynamics_rs.class.getName().split("_")[0].toLowerCase();
		in = new Scanner(new FileReader(problemName + ".in"));
		out = new PrintWriter(new File(problemName + ".out"));
		Thread thread = new Thread(new aerodynamics_rs());
		thread.start();
		thread.join();
		in.close();
		out.close();
	}


}
