#include <iostream>
#include <vector>
#include <string>
#include <algorithm>
#include <map>
#include <cstdlib>
#include <cstdio>
#include <stack>
#include <deque>
#include <queue>
#include <cmath>
#include <ctime>

#define md 10000000007

#define prev(x) ((x) - ((x) & (-x)))
#define next(x) ((x) + ((x) & (-x)))
#define ll long long
#define ull unsigned long long
#define f first
#define s second
#define pii pair < int, int >
#define ppi pair < pii, int >
#define pib pair < int, bool >
#define ppbi pair < int, pib >
#define pb push_back


#ifdef WIN32
    #define I64 I64d
#else
    #define I64 lld
#endif // WIN32
#define mp make_pair

using namespace std;

double sqr(double a)
{
    return a * a;
}

bool doubleEqual(double a, double b)
{
    return fabs(a - b) < 1e-9;
}

bool doubleLessOrEqual(double a, double b)
{
    return a < b || doubleEqual(a, b);
}

bool doubleLess(double a, double b)
{
    return a < b && !doubleEqual(a, b);
}

bool doubleGreateOrEqual(double a, double b)
{
    return a > b || doubleEqual(a, b);
}

bool doubleGreater(double a, double b)
{
    return a > b && !doubleEqual(a, b);
}

double mySqrt(double a)
{
    if (doubleLess(a, 0))
    {
        throw "sqrt(-1)";
    }
    if (a < 0) return 0;
    return sqrt(a);
}

struct Point
{
    public:
        double x, y;
        Point(): x(0), y(0) {}
        Point(double x, double y) : x(x), y(y) {}

        void scan()
        {
            scanf("%lf %lf", &x, &y);
        }

        void print() const
        {
            printf("%.10lf %10lf\n", x, y);
        }

        Point operator+(const Point & p) const
        {
            return Point(x + p.x, y + p.y);
        }

        Point operator-(const Point & p) const
        {
            return Point(x - p.x, y - p.y);
        }

        Point operator-() const
        {
            return Point(-x, -y);
        }

        Point operator*(double k) const
        {
            return Point(x * k, y * k);
        }

        Point operator/(double k) const
        {
            return Point(x / k, y / k);
        }

        double operator%(const Point & p) const
        {
            return x * p.x + y * p.y;
        }

        double operator*(const Point & p) const
        {
            return x * p.y - y * p.x;
        }

        double length() const
        {
            return mySqrt(*this % *this);
        }

        double distTo(const Point & p) const
        {
            return (*this - p).length();
        }

        double distTo(const Point & A, const Point & B) const
        {
            double d = A.distTo(B);
            if (doubleEqual(d, 0))
            {
                throw "A = B";
            }
            double s = (*this - A) * (*this - B);
            return fabs(s) / d;
        }

        Point normalize(double k = 1) const
        {
            double len = length();
            if (doubleEqual(len, 0))
            {
                if (doubleEqual(k, 0))
                {
                    return Point();
                }
                throw "xero-size vector";
            }
            return *this * (k / len);
        }

        Point getH(const Point & A, const Point & B) const
        {
            Point C = *this;
            Point v = B - A;
            Point u = C - A;
            double k = v % u / v.length();
            v = v.normalize(k);
            Point H = A + v;
            return H;
        }

        Point rotate() const
        {
            return Point(-y, x);
        }

        Point rotate(double alpha) const
        {
            return rotate(cos(alpha), sin(alpha));
        }

        Point rotate(double cosa, double sina) const
        {
            Point v = *this;
            Point u = v.rotate();
            Point w = v * cosa + u * sina;
            return w;
        }

        bool isZero() const
        {
            return doubleEqual(x, 0) && doubleEqual(y, 0);
        }

        bool IsOnLine(const Point & A, const Point & B) const
        {
            return doubleEqual((A - *this) * (B - *this), 0);
        }

        bool IsInSegment(const Point & A, const Point & B) const
        {
            return IsOnLine(A, B) && doubleLessOrEqual((A - *this) % (B - *this), 0);
        }

        bool IsInSegmentStrictly(const Point & A, const Point & B) const
        {
            return IsOnLine(A, B) && doubleLess((A - *this) % (B - *this), 0);
        }

        double getAngle() const
        {
            return atan2(y, x);
        }

        double getAngle(Point u) const
        {
            Point v = *this;
            if (u.y == v.y && u.x > v.x) {
                return 0;
            }
            if (u.y == v.y && u.x < v.x) {
                return M_PI;
            }
            if (u.x == v.x && u.y > v.y) {
                return M_PI / 2;
            }
            if (u.x == v.x && u.y < v.y) {
                return -M_PI/2;
            }
            u.x += 5437;
            u.y += 5437;
            v.x += 5437;
            v.y += 5437;
            double result = atan2(v * u, v % u);
            u.x -= 5437;
            u.y -= 5437;
            v.x -= 5437;
            v.y -= 5437;
            return result;
        }

        int GetIntersection
        (const Point & A,
         const Point & B,
         const Point & C,
         const Point & D,
         Point & O)
         {
             Point v = B - A;
             double s1 = (C - A) * (D - A);
             double s2 = (D - B) * (C - B);
             double s = s1 + s2;
             if (doubleEqual(s, 0))
             {
                 if (!A.IsOnLine(C, D))
                 {
                     return 0;
                 }
                 return 2;
             }
             v = v / s;
             v = v * s1;
             O = A + v;
             return 1;
         }

         int GetIntersection
         (const Point & A,
          double rA,
          const Point & B,
          double rB,
          Point & M,
          Point & N)
          {
              double d = A.distTo(B);

              if (doubleLess(rA + rB, d) || doubleLess(d, fabs(rA - rB)))
              {
                  return 0;
              }
              double a = (sqr(rA) - sqr(rB) + sqr(d)) / 2 / d;
              double h = mySqrt(sqr(rA) - sqr(a));
              Point v = B - A;
              Point u = v.rotate();
              v = v.normalize(a);
              u = u.normalize(h);
              Point H = A + v;
              M = H + u;
              N = H - u;
              if (u.isZero()) return 1;
              return 2;
          }

          int GetIntersection
          (
                const Point & A,
                const Point & B,
                const Point & O,
                double r,
                Point & M,
                Point & N
          )
          {
              double h = O.distTo(A, B);
              if (doubleLess(r, h))
              {
                  return 0;
              }
              Point H = O.getH(A, B);
              Point v = B - A;
              double k = mySqrt(sqr(r) - sqr(h));
              v = v.normalize(k);
              M = H + v;
              N = H - v;
              if (v.isZero()) return 1;
              return 2;
          }

          int getTangent
          (
            const Point & A,
            const Point & O,
            double r,
            Point & M,
            Point & N
          )
          {
                Point v = O - A;
                double d = v.length();
                if (doubleLess(d, r)) return 0;
                double alpha = asin(r / d);
                double L = mySqrt(sqr(d) - sqr(r));
                v = v.normalize(L);
                M = A + v.rotate(alpha);
                N = A - v.rotate(alpha);
                if (doubleEqual(r, d)) return 1;
                return 2;
          }

        void getOutTangent
        (
            Point A,
            double rA,
            Point B,
            double rB,
            pair <Point, Point> & P,
            pair <Point, Point> & Q
        )
        {
            if (rA > rB)
            {
                swap(rA, rB);
                swap(A, B);
            }
            double d = A.distTo(B);
            Point u = (A - B).rotate(asin(rA/ d)).rotate().normalize(rA);
            P.f = A + u;
            Q.f = A - u;
            Point T1, T2;
            getTangent(A, B, rB - rA, T1, T2);
            P.second = T1 + u;
            Q.second = T2 - u;
        }
};

struct Point3D
{
    double x, y, z;
        Point3D(): x(0), y(0), z(0) {}
        Point3D(double x, double y, double z) : x(x), y(y), z(z) {}
    public:

        Point3D operator-(const Point3D &p) const
        {
            return Point3D(x - p.x, y - p.y, z - p.z);
        }

        Point3D operator*(const Point3D &p) const
        {
            return
                Point3D
                (
                    y * p.z - z * p.y,
                    z * p.x - x * p.z,
                    x * p.y - y * p.x
                );
        }

        double operator%(const Point3D &p) const
        {
            return x * p.x + y * p.y + z * p.z;
        }
};

double m, h, H;
vector <Point3D> p;

bool comp(pair<double, pair<Point, int> > a1, pair<double, pair<Point, int> > a2)
{
    return a1.first > a2.first;
}

int main() {
    #ifdef DEBUG
        freopen("input.txt", "r", stdin);
        //freopen("output.txt", "w", stdout);
    #else
        //freopen("input.txt", "r", stdin);
        //freopen("output.txt", "w", stdout);
    #endif // DEBUG
    cin >> m >> h >> H;
    for (int i = 0; i < 5; i++)
    {
        Point3D M;
        cin >> M.x >> M.y;
        if (i != 4) M.z = 0;
        else M.z = H;
        p.pb(M);
    }
    Point3D v01 = p[0] - p[1], v02 = p[0] - p[2], v03 = p[0] - p[3], v04 = p[0] - p[4];
    Point3D v42 = p[4] - p[2], v43 = p[4] - p[3], v41 = p[4] - p[1];
    double h1 = (v01*v02)%v04;
    double h2 = (v02*v03)%v04;
    double h3 = (v01*v03)%v04;
    h1 /= ((v42 * v41).z);
    h2 /= ((v42 * v43).z);
    h3 /= ((v43* v41).z);
    double ans = h + min(min(abs(h1), abs(h2)), min(abs(h3), h));
    if (ans > m)
        cout << "NO";
    else cout << "YES";
    return 0;
}
