#include <cstdio>
#include <cstdlib>
#include <cstring>
#include <cassert>
#include <cmath>

#include <iostream>
#include <iomanip>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <deque>
#include <queue>
#include <stack>
#include <algorithm>
#include <iomanip>


#define forn(i, n) for(int i = 0; i < int(n); i++)
#define mp make_pair
#define pb push_back
#define foreach(it, v) for(__typeof(v.begin()) it = v.begin(); it != v.end(); ++it)

using namespace std;

typedef long long ll;

struct Point {
	double x, y;
	Point() : x(0), y(0) {}
	Point(double x, double y) : x(x), y(y) {}
};

struct Line {
	double a, b, c;
	
	double eval(Point p) const {
		return a * p.x + b * p.y + c;
	}
};

const double eps = 1e-9;

Line getLine(Point i, Point j) {
	Line result;
	result.a = j.y - i.y;
	result.b = i.x - j.x;
	result.c = i.y * j.x - i.x * j.y;
	return result;
}

double getMult(Point a, Point b, Point c) {
	double x0 = b.x - a.x;
	double y0 = b.y - a.y;
	double x1 = c.x - a.x;
	double y1 = c.y - a.y;
	return x0 * y1 - x1 * y0;
}

bool isDifferent(double a, double b) {
	if(a > eps && b > eps)
		return false;
	if(a < -eps && b < -eps)
		return false;
	return true;
}

bool isIntersect(Point A0, Point B0, Point A1, Point B1) {
	double x0 = getMult(A0, B0, A1);
	double y0 = getMult(A0, B0, B1);
	
	double x1 = getMult(A1, B1, A0);
	double y1 = getMult(A1, B1, B0);
	
	return isDifferent(x0, y0) && isDifferent(x1, y1);
}

double getDistance(Point a, Point b) {
	double dx = a.x - b.x;
	double dy = a.y - b.y;
	return sqrt(dx * dx + dy * dy);
}

bool isLay(Point A, Point B, Point C) {
	return abs(getMult(A, B, C)) < eps && getDistance(A, C) < getDistance(A, B) + eps;
}

bool isLay(Point A, Point B, Point C, Point D) {
	Line x = getLine(A, B);
	Line y = getLine(B, C);
	Line z = getLine(C, A);
	return x.eval(D) < 0 && y.eval(D) < 0 && z.eval(D) < 0;
}


Point getMiddle(Point A, Point B) {
	double dx = B.x - A.x;
	double dy = B.y - A.y;
	return Point(A.x + dx * 0.5, A.y + dy * 0.5);
}

double getResult(Point A, Point B, Point C, Point F, double square) {
	int commonPoints = 0;
	if(isIntersect(A, B, Point(), F)) {
		//cout << "INTERSECT A B" << endl;
		++commonPoints;
	}
	if(isIntersect(B, C, Point(), F)) {
		//cout << "INTERSECT B C" << endl;
		++commonPoints;
	}
	if(isIntersect(C, A, Point(), F)) {
		//cout << "INTERSECT C A" << endl;
		++commonPoints;
	}
		
	//cout << "COMMON: " << commonPoints << endl;
	
	//assert(commonPoints >= 1 && commonPoints <= 2);
	
	return commonPoints >= 2 ? square : 0.0;
}

double rec(Point A, Point B, Point C, Point F, double square) {
	if(square < eps)
		return 0.0;
		
	/*cout << "ENTER" << endl;
	cout << A.x << " " << A.y << endl;
	cout << B.x << " " << B.y << endl;
	cout << C.x << " " << C.y << endl;
	cout << F.x << " " << F.y << endl;
	*/
	
	Point D = getMiddle(A, C);
		
	double result = getResult(B, D, A, F, square) + getResult(C, D, B, F, square);
	
	
	bool ok = true;
	
	if(isLay(A, B, F) || isLay(B, C, F) || isLay(A, C, F) || isLay(B, D, F))
		ok = false;
		
	if(ok) {
		if(isLay(B, A, D, F)) {
			//cout << "IS LAY" << endl;
			result += rec(B, D, A, F, square / 2);
		} else {
			assert(isLay(C, B, D, F));
			result += rec(C, D, B, F, square / 2);
		}
	}
	
	return result;
}

int main() {
	Point A(0, 0), B(10, 0), C(10, 10);
	Point F;
	cin >> F.x >> F.y;
	double result = rec(C, B, A, F, 25.0);
	cout << setprecision(10) << result << endl;
	return 0;
}
