#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>
#include <ctime>
#include <cstring>
#include <algorithm>
#include <iostream>
#include <set>
#include <map>
#include <vector>
#include <queue>
#include <deque>
using namespace std;
#define pb push_back
#define mp make_pair
#define sc second
#define fs first
#define int64 long long
#define ldb long double
#define sz(a) ((int) (a).size())
#define eprintf(...) fprintf(stderr, __VA_ARGS__)
const double eps = 1e-10;

double sqr(double x) {
	return x * x;
}

struct pt {
	double x, y;
	pt(double x, double y): x(x), y(y) {}
	pt() {}
} p, q;

pt operator-(const pt& a, const pt& b) {
	return pt(a.x - b.x, a.y - b.y);
}

pt operator+(const pt& a, const pt& b) {
	return pt(a.x + b.x, a.y + b.y);
}

pt operator*(const pt& a, double d) {
	return pt(a.x * d, a.y * d);
}

double det2(const double& a, const double& b, const double& c, const double& d) {
	return a * d - b * c;
}

double vmul(const pt& a, const pt& b) {
	return det2(a.x, a.y, b.x, b.y);
}

double smul(const pt& a, const pt& b) {
	return a.x * b.x + a.y * b.y;
}

double dist(const pt& a, const pt& b) {
	return sqrt(sqr(a.x - b.x) + sqr(a.y - b.y));
}

int sign(const double& x) {
	return ((x > eps) ? 1 : ((x < -eps) ? -1 : 0));
}

bool on_segment(const pt& a, const pt& b, const pt& c) {
	return ((sign(vmul(c - a, c - b)) == 0) && (sign(smul(c - a, c - b)) <= 0)); 
}

bool cross(const pt& a, const pt& b, const pt& c, const pt& d) {
	int vm1 = sign(vmul(b - a, c - a)), vm2 = sign(vmul(b - a, d - a));
	if (vm1 * vm2 > 0) return false;
	int vm3 = sign(vmul(d - c, a - c)), vm4 = sign(vmul(d - c, b - c));
	if (vm3 * vm4 > 0) return false;
	if ((vm1 * vm2 < 0) && (vm3 * vm4 < 0)) return true;
	return on_segment(a, b, c) || on_segment(a, b, d) || on_segment(c, d, a) || on_segment(c, d, b);
}

bool bad(const pt& a, const pt& b, const pt& c, const pt& d) {
	int vm1 = sign(vmul(b - a, d - c));
	if (vm1 != 0) return false;
	int vm2 = sign(vmul(b - a, c - a));
	if (vm2 != 0) return false;
	return true;
}

double f(const pt& a, const pt& b, const pt& c) {
	if (bad(a, b, p, q) || bad(a, c, p, q) || bad(b, c, p, q)) return 0.0;
	double sq = dist(a, b) * dist(a, c) / 2.0;
	int cnt = 0;
	cnt += (int) cross(a, b, p, q) + (int) cross(a, c, p, q) + (int) cross(b, c, p, q);
	cnt -= (int) on_segment(p, q, a) + (int) on_segment(p, q, b) + (int) on_segment(p, q, c);
	if (cnt == 2) return sq;
	if ((cnt == 0) || (sq < eps)) return 0.0;
	pt d = (b + c) * 0.5;
	return f(d, a, b) + f(d, a, c);
}

int main() {
	//double start = clock();
	//assert(freopen("input.txt", "r", stdin));
	//assert(freopen("output.txt", "w", stdout));
	scanf("%lf%lf", &p.x, &p.y);
	q = pt(0, 0);
	printf("%.10lf\n", f(pt(10, 0), pt(0, 0), pt(10, 10)));
	//eprintf("%.2lf\n", (clock() - start) / CLOCKS_PER_SEC);
	return 0;
}