#include <cstdio>
#include <cstdlib>
#include <cmath>
#include <cassert>
#include <ctime>
#include <cstring>
#include <algorithm>
#include <iostream>
#include <set>
#include <map>
#include <vector>
#include <queue>
#include <deque>
using namespace std;
#define pb push_back
#define mp make_pair
#define sc second
#define fs first
#define int64 long long
#define ldb long double
#define double long double
#define sz(a) ((int) (a).size())
#define eprintf(...) fprintf(stderr, __VA_ARGS__)

const int size = 1000 * 1000;
const double inf = 1e9;
const double eps = 1e-9;
const double pi = acos(-1.0);
const double eps2 = 1e-5;

inline double sqr(double x) {
	return x * x;
}

struct point {
	double x, y;
	point (double x_ = 0.0, double y_ = 0.0) : x(x_), y(y_) {}

	double dist(const point& p) const {
		return sqrt(sqr(p.x - x) + sqr(p.y - y));
	}
};

point operator + (const point& a, const point& b) {
	return point(a.x + b.x, a.y + b.y);
}

point operator - (const point& a, const point& b) {
	return point(a.x - b.x, a.y - b.y);
}

double vmult(const point& a, const point& b) {
	return a.x * b.y - a.y * b.x;
}

struct line {
	double a, b, c;
	line(double a_ = 1.0, double b_ = 0.0, double c_ = 0.0) : a(a_), b(b_), c(c_) {
		norm();
	}

	line(const point& p1, const point& p2) {
		a = p2.y - p1.y;
		b = p1.x - p2.x;
		c = - a * p1.x - b * p1.y;
		norm();
	}

	void norm() {
		double k = sqrt(sqr(a) + sqr(b));

		a /= k;
		b /= k;
		c /= k;
	}

	double dist(const point& p) const {
		double d = a * p.x + b * p.y + c;
		return d;
	}
};

bool cross(const line& l1, const line& l2, point& p) {
	double d = l1.a * l2.b - l1.b * l2.a;
	if (fabs(d) < eps)
		return false;
	p.x = (l1.b * l2.c - l2.b * l1.c) / d;
	p.y = (l2.a * l1.c - l1.a * l2.c) / d;

	//assert(fabs(l1.dist(p)) < eps);
	//assert(fabs(l2.dist(p)) < eps);

	return true;
}

bool complines(const pair <pair <double, double>,  line>& a, const pair <pair <double, double>,  line>& b) {
	if (fabs(a.fs.fs - b.fs.fs) < eps)
		return a.fs.sc < b.fs.sc;
	else
		return a.fs.fs < b.fs.fs;
}

vector <point> tovector(deque<point> dq) {
	vector <point> res;
	while (!dq.empty()) {
		res.pb(dq.front());
		dq.pop_front();
	}

	return res;
}

vector <point> buildcrossing(vector <line> lines) {
	point upleft(-inf, inf);
	point downleft(-inf, -inf);
	point upright(inf, inf);
	point downright(inf, -inf);

	line rightline(1.0, 0.0, inf);
	line leftline(-1.0, 0.0, inf);
	line upline(0.0, -1.0, inf);
	line downline(0.0, 1.0, inf);
	
	lines.pb(downline);
	lines.pb(rightline);
	lines.pb(upline);
	lines.pb(leftline);

	vector <pair <pair <double, double>, line> > tosort;
	for (int i = 0; i < (int) lines.size(); i++) {
		tosort.pb(mp(mp(atan2(lines[i].b, lines[i].a), lines[i].c), lines[i]));
		if (tosort.back().fs.fs < 0)
			tosort.back().fs.fs += 2 * pi;
	}

	sort(tosort.begin(), tosort.end(), complines);

	lines.clear();
	for (int i = 0; i < (int) tosort.size(); i++)
		if ((i == 0) || tosort[i].fs.fs > tosort[i - 1].fs.fs + eps)
			lines.pb(tosort[i].sc);

	deque <point> ptsans;
	deque <line> lineans;

	ptsans.pb(point(-lines[0].c, inf * inf));
	lineans.pb(lines[0]);
	for (int i = 1; i < (int) lines.size(); i++) {
		while (!ptsans.empty() && lines[i].dist(ptsans.back()) < -eps2) {
			ptsans.pop_back();
			lineans.pop_back();
		}

		if (lineans.empty())
			return tovector(ptsans);
		point h;
		if (cross(lineans.back(), lines[i], h)) {
			if (lineans[0].dist(h) > -eps2) {
				lineans.pb(lines[i]);
				ptsans.pb(h);
			}
		}

		bool flag = false;
		line lst;
		while (!ptsans.empty() && lines[i].dist(ptsans.front()) < -eps2) {
			flag = true;
			lst = lineans.front();

			ptsans.pop_front();
			lineans.pop_front();
		}

		if (lineans.empty())
			return tovector(ptsans);
	
		if (flag) {
			point h;
			if (cross(lst, lines[i], h)) {
				if (lineans.back().dist(h) > -eps2) {
					lineans.push_front(lst);
					ptsans.push_front(h);
				}
			}
		}
	}

	return tovector(ptsans);
}

int main() {
	//assert(freopen("input.txt", "r", stdin));
	//assert(freopen("output.txt", "w", stdout));

	int n;
	scanf("%d", &n);
	vector <line> lines;
	for (int i = 0; i < n; i++) {
		int a, b, c;
		scanf("%d%d%d", &a, &b, &c);

		lines.pb(line(-a, -b, c));
	}

	vector <point> hull = buildcrossing(lines);

	if (hull.empty()) {
		cout << 0 << endl;
	} else {
		double mx = 0.0;
		for (int i = 0; i < (int) hull.size(); i++)
			mx = max(mx, max(fabs(hull[i].x), fabs(hull[i].y)));
		double sum = 0.0;
		for (int i = 0; i < (int) hull.size(); i++) {
			sum += vmult(hull[i], hull[(i + 1) % (int) hull.size()]);
		}

		if (fabs(sum) > eps && mx > inf / 2.0) {
			cout << -1 << endl;
		} else {
			cout.precision(20);
			cout << fabs(sum) / 2.0 << endl;
			//printf("%.10lf\n", fabs(sum) / 2.0);
		}
	}

	return 0;
}