#include <iostream> 
#include <cstdio> 
#include <map> 
#include <set> 
#include <algorithm> 
#include <cstdlib> 
#include <cstring>
#include <cassert>
#include <utility>
#include <vector>
#include <string>
#include <queue>
#include <fstream> 
#include <iomanip> 
#include <sstream> 
#include <cmath> 
#include <ctime> 
#include <cctype> 
#include <deque> 

#define pb push_back
#define mp make_pair

using namespace std;

typedef long long ll;
typedef unsigned long long ull;
typedef long double ld;
typedef pair< int, int > pii;
typedef vector< int > vi;

template <class T> inline void updMax(T &x, const T &other) { if (x < other) x = other; }
template <class T> inline void updMin(T &x, const T &other) { if (other < x) x = other; }
template <class T> inline T sqr(const T &x) { return x * x; } 

struct Point3D
{
	ld x, y, z;
	Point3D(ld x_ = 0., ld y_ = 0., ld z_ = 0.) : x(x_), y(y_), z(z_) {}
	Point3D operator+(const Point3D &lhs) const
	{
		return Point3D(x + lhs.x, y + lhs.y, z + lhs.z);
	}
	Point3D operator-(const Point3D &lhs) const
	{
		return Point3D(x - lhs.x, y - lhs.y, z - lhs.z);
	}
	ld operator*(const Point3D &lhs) const
	{
		return x * lhs.x + y * lhs.y + z * lhs.z;
	}
	Point3D operator*(const ld alpha) const
	{
		return Point3D(x * alpha, y * alpha, z * alpha);
	}
	friend istream& operator>>(istream &in, Point3D &p)
	{
		return in >> p.x >> p.y >> p.z;
	}
};

vector< Point3D > allP;
int n, zmin, zmax;

struct Point2D
{
	ld x, y;
	Point2D(ld x_ = 0., ld y_ = 0.) : x(x_), y(y_) {}
	Point2D operator+(const Point2D &lhs) const
	{
		return Point2D(x + lhs.x, y + lhs.y);
	}
	Point2D operator-(const Point2D &lhs) const
	{
		return Point2D(x - lhs.x, y - lhs.y);
	}
	ld operator^(const Point2D &lhs) const
	{
		return x * lhs.y - y * lhs.x;
	}
	ld sqLen() const
	{
		return x * x + y * y;
	}
	bool operator<(const Point2D &lhs) const
	{
		return x < lhs.x - 1e-9 || fabs(x - lhs.x) < 1e-9 && y < lhs.y - 1e9;
	}
};

bool cmp(const Point2D &a, const Point2D &b)
{
	ld cp = a ^ b;
	return (cp > 1e-9 || fabs(cp) < 1e-9 && a.sqLen() < b.sqLen());
}

bool canIsect(const Point3D &x, const Point3D &y, ld zcoord, Point2D &res)
{
	Point3D norm(0, 0, 1.);
	if (fabs(x.z - y.z) < 1e-9) {
		return false;
	}
	ld cur = (zcoord - x.z) / (y.z - x.z);
	if (cur < 1e-9 || cur > 1 + 1e-9) {
		return false;
	}
	Point3D tmp = x + (y - x) * cur;
	res = Point2D(tmp.x, tmp.y);
	return true;
}

vector< Point2D > pnts;

ld
getConvexHull(vector< Point2D > vc)
{
	int id = 0;
	for (int i = 0; i < int(vc.size()); ++i) {
		if (vc[i] < vc[id]) {
			id = i;
		}
	}
	vector< Point2D > tmp;
	Point2D null = vc[id];
	for (int i = 0; i < int(vc.size()); ++i) {
		vc[i] = vc[i] - null;
		if (vc[i].sqLen() > 1e-9) {
			tmp.push_back(vc[i]);
		}
	}
	sort(tmp.begin(), tmp.end(), cmp);
	vector< Point2D > stck;
	stck.push_back(Point2D());
	int stcnt = 1;
	for (int i = 0; i < int(tmp.size()); ++i) {
		while (stcnt > 1) {
			if (((stck[stcnt - 1] - stck[stcnt - 2]) ^ (tmp[i] - stck[stcnt - 1])) > 1e-9) {
				break;
			}
			stck.pop_back();
			--stcnt;
		}
		stck.push_back(tmp[i]);
		++stcnt;
	}
	if (stcnt < 3) {
		return 0.0;
	}
	ld res = 0.;
	for (int i = 1; i < int(stck.size()); ++i) {
		res += stck[i] ^ stck[i - 1];
	}
	res += stck.back() ^ stck[0];
	return fabs(res) / 2;
}

ld
check(ld dist)
{
	pnts.clear();
	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < n; ++j) {
			Point2D tmp;
			if (canIsect(allP[i], allP[j], dist, tmp)) {
				pnts.push_back(tmp);
			}
		}
	}
	return getConvexHull(pnts);
}

int main()
{
	//freopen("input.txt", "r", stdin); freopen("output.txt", "w", stdout);
	//freopen(".in", "r", stdin); freopen(".out", "w", stdout);
	
	//ios::sync_with_stdio(false); 
	cin >> n >> zmin >> zmax;
	allP.resize(n);
	for (int i = 0; i < n; ++i) {
		cin >> allP[i];
	}
	cout << fixed << setprecision(10);
	for (int it = zmin; it <= zmax; ++it) {
		cout << check(it) << '\n';
	}
	return 0;
}