#include <iostream> 
#include <cstdio> 
#include <map> 
#include <set> 
#include <algorithm> 
#include <cstdlib> 
#include <cstring>
#include <cassert>
#include <utility>
#include <vector>
#include <string>
#include <queue>
#include <fstream> 
#include <iomanip> 
#include <sstream> 
#include <cmath> 
#include <ctime> 
#include <cctype> 
#include <deque> 

#define pb push_back
#define mp make_pair

using namespace std;

typedef long double ll;
typedef unsigned long long ull;
typedef long double ld;
typedef pair< int, int > pii;
typedef vector< int > vi;

template <class T> inline void updMax(T &x, const T &other) { if (x < other) x = other; }
template <class T> inline void updMin(T &x, const T &other) { if (other < x) x = other; }
template <class T> inline T sqr(const T &x) { return x * x; } 

const int MAXN = 100;

bool used[MAXN][MAXN][MAXN];

struct Point3D
{
	ll x, y, z;
	Point3D(ll x_ = 0, ll y_ = 0, ll z_ = 0) : x(x_), y(y_), z(z_) {}
	Point3D operator-(const Point3D &lhs) const
	{
		return Point3D(x - lhs.x, y - lhs.y, z - lhs.z);
	}
	Point3D operator+(const Point3D &lhs) const
	{
		return Point3D(x + lhs.x, y + lhs.y, z + lhs.z);
	}
	Point3D operator^(const Point3D &lhs) const
	{
		return Point3D(y * lhs.z - z * lhs.y, z * lhs.x - x * lhs.z, x * lhs.y - y * lhs.x);
	}
	ll operator*(const Point3D &lhs) const
	{
		return x * lhs.x + y * lhs.y + z * lhs.z;
	}
	ld len() const
	{
		return sqrt(ld(x * x + y * y + z * z));
	}
	friend istream& operator>>(istream &in, Point3D &p)
	{
		return in >> p.x >> p.y >> p.z;
	}
	friend Point3D operator*(ld alpha, Point3D &lhs)
	{
		return Point3D(alpha * lhs.x, alpha * lhs.y, alpha * lhs.z);
	}
	bool operator<(const Point3D &lhs) const
	{
		return (x < lhs.x - 1e-9 ||
			fabs(x - lhs.x) < 1e-9 && y < lhs.y - 1e-9 ||
			fabs(x - lhs.x) < 1e-9 && fabs(y - lhs.y) < 1e-9 && z < lhs.z - 1e-9);
	}
	friend ostream &operator<<(ostream &out, const Point3D &p)
	{
		return out << "(" << p.x << ", " << p.y << ", " << p.z << ")";
	}
};

struct Comp
{
	Point3D norm;
	Comp(Point3D p) : norm(p) {}
	bool operator()(const Point3D &a, const Point3D &b) const
	{
		ll volume = (a ^ b) * norm;
		return (volume > 1e-9 || fabs(volume) < 1e-9 && a.len() < b.len() - 1e-9);
	}
};

struct Plane3D
{
	Point3D arr[3];
	Plane3D() {}
	Plane3D(const Point3D &x, const Point3D &y, const Point3D &z)
	{
		arr[0] = x;
		arr[1] = y;
		arr[2] = z;
		//cout << x << " " << y << " " << z << "\n";
	}
	ll getOrVol(const Point3D &p) const
	{
		return ((arr[1] - arr[0]) ^ (arr[2] - arr[0])) * (p - arr[0]);
	}
	int getSign(const Point3D &p) const
	{
		ll volume = getOrVol(p);
		if (volume > 0) {
			return 1;
		}
		return (volume == 0) ? 0 : -1;
	}
	ld dist(const Point3D &p) const
	{
		ll volume = getOrVol(p);
		ll square = ((arr[1] - arr[0]) ^ (arr[2] - arr[0])).len();
		return fabs(volume / square);
	}
};

vector< Point3D > allP;
vector< Plane3D > allPlanes;

void
getConvexHull(vector< Point3D > &arr, const Point3D &norm)
{
	int id = 0;
	int cnt = arr.size();
	for (int i = 0; i < cnt; ++i) {
		if (arr[i] < arr[id]) {
			id = i;
		}
	}
	Point3D null = arr[id];
	vector< Point3D > tmp;
	for (int i = 0; i < cnt; ++i) {
		arr[i] = arr[i] - null;
		if (arr[i].len() > 1e-9) {
			tmp.push_back(arr[i]);
		}
	}
	sort(tmp.begin(), tmp.end(), Comp(norm));
	vector< Point3D > stack;
	int st = 1;
	stack.push_back(Point3D());
	for (int i = 0; i < int(tmp.size()); ++i) {
		while (st > 1) {
			if (((stack[st - 1] - stack[st - 2]) ^ (tmp[i] - stack[st - 1])) * norm > 1e-9) {
				break;
			}
			--st;
			stack.pop_back();
		}
		++st;
		stack.push_back(tmp[i]);
	}
	for (int i = 0; i < st; ++i) {
		stack[i] = stack[i] + null;
	}
	for (int i = 2; i < st; ++i) {
		allPlanes.push_back(Plane3D(stack[0], stack[i - 1], stack[i]));
	}
}

void
process(ld &ans)
{
	allP.clear();
	allPlanes.clear();
	int n;
	cin >> n;
	allP.resize(n);
	for (int i = 0; i < n; ++i) {
		cin >> allP[i];
	}
	for (int i = 0; i < n; ++i) {
		for (int j = 0; j < n; ++j) {
			for (int k = 0; k < n; ++k) {
				used[i][j][k] = false;
			}
		}
	}
	for (int i = 0; i < n - 2; ++i) {
		for (int j = i + 1; j < n - 1; ++j) {
			for (int k = j + 1; k < n; ++k) {
				if (((allP[i] - allP[j]) ^ (allP[k] - allP[j])).len() < 1e-9) {
					continue;
				}
				if (used[i][j][k]) {
					continue;
				}
				int minSign = 2;
				int maxSign = -2;
				Plane3D checkPlane(allP[i], allP[j], allP[k]);
				vector< int > ids;
				vector< Point3D > curP;
				for (int tt = 0; tt < n; ++tt) {
					int curSign = checkPlane.getSign(allP[tt]);
					minSign = min(minSign, curSign);
					maxSign = max(maxSign, curSign);
					if (curSign == 0) {
						ids.push_back(tt);
						curP.push_back(allP[tt]);
					}
				}
				if (minSign * maxSign < 0) {
					continue;
				}
				// it's a plane;
				int cnt = ids.size();
				for (int l = 0; l < cnt; ++l) {
					for (int l1 = 0; l1 < cnt; ++l1) {
						for (int l2 = 0; l2 < cnt; ++l2) {
							used[ids[l]][ids[l1]][ids[l2]] = true;
						}
					}
				}				
				getConvexHull(curP, (allP[i] - allP[j]) ^ (allP[k] - allP[j]));
			}
		}
	}
	Point3D someInner;
	for (int i = 0; i < n; ++i) {
		someInner = someInner + allP[i];
	}
	someInner = (1. / n) * someInner;
	ll allVolume = 0;
	Point3D center;
	Point3D sum;
	for (int ii = 0; ii < int(allPlanes.size()); ++ii) {
		const Plane3D &curPlane = allPlanes[ii];
		ll volume = fabs(curPlane.getOrVol(someInner)) / 6.;
		allVolume += volume;
		Point3D addPoint = (1. / 4) * (curPlane.arr[0] + curPlane.arr[1] + curPlane.arr[2] + someInner);
		//cout << addPoint << '\n';
		//sum = sum + addPoint;
		center = center + volume * addPoint; 
	}
	//cout << sum << endl;
	center = 1. / allVolume * center;
	ans = 1e9;
	for (int ii = 0; ii < int(allPlanes.size()); ++ii) {
		ans = min(ans, allPlanes[ii].dist(center));
	}
	//cout << ans << '\n';
	//cout << "Zo" << endl;
}

int main()
{
	//freopen("input.txt", "r", stdin); freopen("output.txt", "w", stdout);
	//freopen(".in", "r", stdin); freopen(".out", "w", stdout);
	
	//ios::sync_with_stdio(false); 
	ld a1 = 0, a2 = 0;
	process(a1);
	process(a2);
	cout << fixed << setprecision(10) << a1 + a2 << '\n';

	return 0;
}