#include <iostream>
#include <algorithm>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <bitset>
#include <sstream>
#include <cstdio>
#include <cstring>
#include <cmath>
#include <climits>
#include <cctype>
#include <cstdlib>
using namespace std;

#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=(a);i--)

typedef long long LL;
typedef LL ll;
typedef pair<int, int> pii;
const int INF = 1000000000;
const LL LINF = 1000000000000000000LL;
const double PI = 3.1415926535897932384626433832795;
const double EPS = 1e-8;

struct Vector2D {
  double x, y;

  Vector2D(double x = 0.0, double y = 0.0) : x(x), y(y) {}
};

Vector2D operator+(const Vector2D& u, const Vector2D& v) {
  return Vector2D(u.x + v.x, u.y + v.y);
}

Vector2D operator-(const Vector2D& u, const Vector2D& v) {
  return Vector2D(u.x - v.x, u.y - v.y);
}

double dot(const Vector2D& u, const Vector2D& v) {
  return u.x * v.x + u.y * v.y;
}

double cross(const Vector2D& u, const Vector2D& v) {
  return u.x * v.y - u.y * v.x;
}

Vector2D operator*(double k, const Vector2D& u) {
  return Vector2D(k * u.x, k * u.y);
}
Vector2D operator*(const Vector2D& u, double k) {
  return Vector2D(k * u.x, k * u.y);
}
typedef Vector2D Point2D;

struct Vector {
  double x, y, z;

  Vector(double x = 0.0, double y = 0.0, double z = 0.0) : x(x), y(y), z(z) {}
};

Vector operator+(const Vector& u, const Vector& v) {
  return Vector(u.x + v.x, u.y + v.y, u.z + v.z);
}

Vector operator-(const Vector& u, const Vector& v) {
  return Vector(u.x - v.x, u.y - v.y, u.z - v.z);
}

double dot(const Vector& u, const Vector& v) {
  return u.x * v.x + u.y * v.y + u.z * v.z;
}
Vector cross(Vector const& a, Vector const& b) {
  return Vector(a.y * b.z - a.z * b.y,
                a.z * b.x - a.x * b.z,
                a.x * b.y - a.y * b.x);
}
double length(Vector const& a) {
  return sqrt(dot(a, a));
}

Vector operator - (Vector const& a) {
  return Vector(-a.x, -a.y, -a.z);
}

Vector operator*(double k, const Vector& u) {
  return Vector(k * u.x, k * u.y, k * u.z);
}
Vector operator*(const Vector& u, double k) {
  return Vector(k * u.x, k * u.y, k * u.z);
}

typedef Vector Point;

struct Plane {
  Vector normal;
  double dist;
  Plane() {}
  Plane(Vector const& v, double d) : normal(v), dist(d) {
    double x = 1 / length(normal);
    normal = normal * x;
    dist *= x;
  }
};
vector<Plane> hull;
vector<Point> points;
bool v3equal(Plane const& a, Plane const& b) {
  return (fabs(a.normal.x - b.normal.x) < EPS) &&
         (fabs(a.normal.y - b.normal.y) < EPS) &&
         (fabs(a.normal.z - b.normal.z) < EPS);
}
bool v3less(Plane const& a, Plane const& b) {
  if (fabs(a.normal.x - b.normal.x) > EPS) return a.normal.x < b.normal.x;
  if (fabs(a.normal.y - b.normal.y) > EPS) return a.normal.y < b.normal.y;
  if (fabs(a.normal.z - b.normal.z) > EPS) return a.normal.z < b.normal.z;
  return a.dist < b.dist;
}
void HullAdd(Vector n, double d) {
  if (length(n) < EPS) return;
  for (int i = 0; i < points.size(); i++) {
    if (dot(points[i], n) + d > EPS) {
      return;
    }
  }
  hull.push_back(Plane(n, d));
}

void BuildHull() {
  for (int i = 0; i < points.size(); i++) {
    for (int j = i + 1; j < points.size(); j++) {
      /*int k = 0;
      Point a = points[i];
      Point b = points[j];
      while (k == i || k == j) k++;
      Point left = points[k], right = points[k];
      Vector nleft = cross(left - a, b - a), nright = cross(right - b, a - b);
      double dleft = dot(nleft, a), dright = dot(nright, b);
      for (k++; k < points.size(); k++) {
        if (k == i || k == j) continue;
        if (dot(points[k], nleft) > dleft) {
          left = points[k];
          nleft = cross(left - a, b - a);
          dleft = dot(nleft, a);
        }
        if (dot(points[k], nright) > dright) {
          right = points[k];
          nright = cross(right - b, a - b);
          dright = dot(nright, b);
        }
      }
      */
      for (int k = j + 1; k < points.size(); k++) {
        Vector n = cross(points[k] - points[i], points[j] - points[i]);
        HullAdd(n, -dot(points[i], n));
        HullAdd(-n, dot(points[i], n));
      }
//      HullAdd(nleft, -dleft);
//      HullAdd(nright, -dright);
    }
  }
}

struct Edge {
  Point a;
  Point b;
  Edge() {}
  Edge(Point const& a, Point const& b) : a(a), b(b) {}
};
vector<Edge> edges;

Point p0;
Vector normal(0, 0, 1);
bool p3less(Point const& a, Point const& b) {
  if (fabs(a.x - b.x) > EPS) return a.x < b.x;
  if (fabs(a.y - b.y) > EPS) return a.y < b.y;
  return a.z < b.z;
}
bool p3equal(Point const& a, Point const& b) {
  return (fabs(a.x - b.x) < EPS) &&
         (fabs(a.y - b.y) < EPS) &&
         (fabs(a.z - b.z) < EPS);
}
bool p3less2(Point const& a, Point const& b) {
  return dot(cross(a - p0, b - p0), normal) < 0;
}

void AddPlane(Plane const& p) {
  vector<Point> pt;
  for (int i = 0; i < points.size(); i++) {
    if (fabs(dot(points[i], p.normal) + p.dist) < EPS) {
      pt.push_back(points[i]);
    }
  }
  sort(pt.begin(), pt.end(), p3less);
  p0 = pt[0];
  normal = p.normal;
  sort(pt.begin() + 1, pt.end(), p3less2);
  pt.push_back(pt[0]);
  for (int i = 1; i < pt.size(); i++) {
    edges.push_back(Edge(pt[i - 1], pt[i]));
  }
}

double GetArea(double z) {
  normal = Vector(0, 0, 1);
  vector<Point> pt;
  for (int i = 0; i < edges.size(); i++) {
    Point a = edges[i].a;
    Point b = edges[i].b;
    if ((a.z - z) * (b.z - z) < EPS) {
      if (fabs(a.z - b.z) < EPS) {
        pt.push_back(a);
      } else {
        pt.push_back(a + (b - a) * ((z - a.z) / (b.z - a.z)));
      }
    }
  }
  sort(pt.begin(), pt.end(), p3less);
  pt.resize(unique(pt.begin(), pt.end(), p3equal) - pt.begin());
  p0 = pt[0];
  sort(pt.begin() + 1, pt.end(), p3less2);
  double answer = 0;
  for (int i = 2; i < pt.size(); i++) {
    answer += length(cross(pt[i] - pt[0], pt[i - 1] - pt[0])) * 0.5;
  }
  return answer;
}

int main() {
  int n, z0, z1;
  cin >> n >> z0 >> z1;
  double zmin = 1e+9, zmax = 1e-9;
  FOR(i, 0, n) {
    double x, y, z;
    cin >> x >> y >> z;
    points.push_back(Vector(x, y, z));
    zmin = min(zmin, z);
    zmax = max(zmax, z);
  }
  BuildHull();
  sort(hull.begin(), hull.end(), v3less);
  hull.resize(unique(hull.begin(), hull.end(), v3equal) - hull.begin());
  for (int i = 0; i < hull.size(); i++) {
    AddPlane(hull[i]);
  }
  cout.precision(9);
  for (int z = z0; z <= z1; z++) {
    if (z < zmin - EPS || z > zmax + EPS) {
      cout << "0\n";
    } else {
      cout << fixed << GetArea(z) << "\n";
    }
  }
  return 0;
}
