#include <cstdio>
#include <iostream>
#include <vector>
#include <algorithm>
#include <cstring>
#include <string>
#include <cmath>
#include <map>
#include <set>
#include <climits>
#include <cassert>
#include <cctype>
#include <queue>
using namespace std;

typedef long long ll;
typedef double dbl;
typedef long double ld;

#define mp make_pair
#define pb push_back
#define sz(x) (int)x.size()
#define all(x) x.begin(),x.end()
#define X first
#define Y second

const ll maxn = 5000*100 + 10;
const dbl eps = 1e-9;

bool is_equal(dbl a, dbl b) {
	return fabs(a - b) < eps;
}

bool is_less(dbl a, dbl b) {
	return !is_equal(a, b) && a < b;
}

bool is_bigger(dbl a, dbl b) {
	return !is_equal(a, b) && a > b;
}

bool is_equal_less(dbl a, dbl b) {
	return is_equal(a, b) || is_less(a, b);
}

bool is_equal_bigger(dbl a, dbl b) {
	return is_equal(a, b) || is_bigger(a, b);
}

struct Point {
	dbl x, y, z;
	Point() {};
	Point(dbl x, dbl y, dbl z) : x(x), y(y), z(z) {};

	void scan() {
		printf("%lf %lf", &x, &y);
	}
	
	void print() {
		printf("%.10lf %.10lf\n", x, y);
	}

	Point operator+(const Point &p) const {
		return Point(x + p.x, y + p.y, z + p.z);
	}

	Point operator-(const Point &p) const {
		return Point(x - p.x, y - p.y, z - p.z);
	}
};

struct Plane {
	double a, b, c, d;
};

double det (double a, double b, double c, double d) {
	return a*d - b*c;
}

Plane make_plane(Point a, Point b, Point c) {
	Plane p;
	p.a = det(b.y - a.y, b.z - a.z, c.y - a.y, c.z - a.z);
	p.b = -det(b.x - a.x, b.z - a.z, c.x - a.x, c.z - a.z);
	p.c = det(b.x - a.x, b.y - a.y, c.x - a.x, c.y - a.y);
	p.d = -(p.a*a.x + p.b*a.y + p.c*a.z);
	return p;
}

double dist(Plane pl, Point p) {
	return fabs(pl.a*p.x + pl.b*p.y + pl.c*p.z + pl.d)/sqrt(pl.a*pl.a + pl.b*pl.b + pl.c*pl.c);
}


int main() {
#ifdef _MBCS
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif
	double m, h, H;
	scanf("%lf %lf %lf", &m, &h, &H);

	double x0, y0;
	scanf("%lf %lf", &x0, &y0);

	double x1, y1;
	scanf("%lf %lf", &x1, &y1);
	Point a = Point(x1, y1, 0.0);

	double x2, y2;
	scanf("%lf %lf", &x2, &y2);
	Point b = Point(x2, y2, 0.0);

	double x3, y3;
	scanf("%lf %lf", &x3, &y3);
	Point c = Point(x3, y3, 0.0); 
	
	double x4, y4;
	scanf("%lf %lf", &x4, &y4);
	Point d = Point(x4, y4, H);

	if (is_less(m, h)) {
		puts("NO");
	}
	else {
		double r = m - h;
		Point cur = Point(x0, y0, h);
		Plane p1 = make_plane(a, b, c);
		Plane p2 = make_plane(a, b, d);
		Plane p3 = make_plane(a, c, d);
		Plane p4 = make_plane(b, c, d);
		if (!is_less(r, dist(p1, cur)))
			puts("YES");
		else if (!is_less(r, dist(p2, cur)))
			puts("YES");
		else if (!is_less(r, dist(p3, cur)))
			puts("YES");
		else if (!is_less(r, dist(p4, cur)))
			puts("YES");
		else
			puts("NO");
	}
	
	
	return 0;
}