#include <cstdio>
#include <iostream>
#include <vector>
#include <algorithm>
#include <cstring>
#include <string>
#include <cmath>
#include <map>
#include <set>
#include <climits>
#include <cassert>
#include <cctype>
#include <queue>
#include <ctime>
using namespace std;

typedef long long ll;
typedef double dbl;
typedef long double ld;

#define mp make_pair
#define pb push_back
#define sz(x) (int)x.size()
#define all(x) x.begin(),x.end()
#define X first
#define Y second

const ll maxn = 5000*100 + 10;
const dbl eps = 1e-9;

bool is_equal(dbl a, dbl b) {
	return fabs(a - b) < eps;
}

bool is_less(dbl a, dbl b) {
	return !is_equal(a, b) && a < b;
}

bool is_bigger(dbl a, dbl b) {
	return !is_equal(a, b) && a > b;
}

bool is_equal_less(dbl a, dbl b) {
	return is_equal(a, b) || is_less(a, b);
}

bool is_equal_bigger(dbl a, dbl b) {
	return is_equal(a, b) || is_bigger(a, b);
}

struct Point {
	dbl x, y;
	int pos;
	Point() {};
	Point(dbl x, dbl y) : x(x), y(y) {};

	void scan() {
		scanf("%lf %lf", &x, &y);
	}
	
	void print() {
		printf("%.10lf %.10lf\n", x, y);
	}

	Point operator+(const Point &p) const {
		return Point(x + p.x, y + p.y);
	}

	Point operator-(const Point &p) const {
		return Point(x - p.x, y - p.y);
	}
	
	Point operator*(const double &k) const {
		return Point(x*k, y*k);
	}

	bool operator<(const Point &p) const {
		return x < p.x || x == p.x && y < p.y;
	}
	
	bool operator==(const Point &p) const {
		return is_equal(x, p.x) && is_equal(y, p.y);
	}
};

struct Plane {
	double a, b, c, d;
};

double det (double a, double b, double c, double d) {
	return a*d - b*c;
}

Plane make_plane(Point a, Point b, Point c) {
	Plane p;
	/*(p.a = det(b.y - a.y, b.z - a.z, c.y - a.y, c.z - a.z);
	p.b = -det(b.x - a.x, b.z - a.z, c.x - a.x, c.z - a.z);
	p.c = det(b.x - a.x, b.y - a.y, c.x - a.x, c.y - a.y);
	p.d = -(p.a*a.x + p.b*a.y + p.c*a.z);*/
	return p;
}

double dist(Plane pl, Point p) {
	//return fabs(pl.a*p.x + pl.b*p.y + pl.c*p.z + pl.d)/sqrt(pl.a*pl.a + pl.b*pl.b + pl.c*pl.c);
	return 0.0;
}

bool cmp (Point a, Point b) {
	return a.x < b.x || a.x == b.x && a.y < b.y;
}

bool cw (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y) < 0;
}

bool ccw (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y) > 0;
}

void convex_hull_greham(vector <Point> & a) {
	if (a.size() == 1) return;
	sort(all(a), cmp);
	Point p1 = a[0], p2 = a.back();
	vector <Point> up, down;
	up.pb(p1);
	down.pb(p1);
	for (int i = 1; i < sz(a); i++) {
		if (i == sz(a) - 1 || cw(p1, a[i], p2)) {
			while (sz(up) >= 2 && !cw(up[sz(up) - 2] ,up[sz(up) - 1], a[i]))
				up.pop_back();
			up.pb(a[i]);
		}
		if (i == sz(a) - 1 || ccw(p1, a[i], p2)) {
			while (sz(down) >= 2 && !ccw(down[sz(down) - 2], down[sz(down) - 1], a[i]))
				down.pop_back();
			down.pb(a[i]);
		}
	}
	a.clear();
	for (int i = 0; i < sz(up); i++)
		a.pb(up[i]);
	for (int i = sz(down) - 2; i > 0; i--)
		a.pb(down[i]);
}

bool isInside (Point a, Point b, Point c) {
	return (a.x <= b.x && b.x <= c.x && a.y <= b.y && b.y <= c.y);
}

bool isStrictlyInside (Point a, Point b, Point c) {
	return isInside(a, b, c) && (!(b == c)) && (!(b == a));
}

double f (Point a, Point b, Point c) {
	return a.x*(b.y - c.y) + b.x*(c.y - a.y) + c.x*(a.y - b.y);
}

void convex_hull_jarvis(vector <Point> & a) {
	if (a.size() == 1) return;
	sort(all(a), cmp);

	vector <Point> hull;
	Point p0 = a[0];
	hull.pb(p0);

	int first = 0, cur = 0;
	do {
		int next = (cur + 1) % (sz(a));
		for (int i = 0; i < sz(a); i++) {
			double sign = f(a[cur], a[next], a[i]);
			if (is_less(sign, 0))
				next = i;
			else if (is_equal(sign, 0)) {
				if (isInside(a[cur], a[next], a[i]))
					next = i;
			}
		}
		cur = next;
		hull.pb(a[next]);
	}
	while (cur != first);
	a.pop_back();
	a = hull;
	
}

void convex_hull_ks (vector <Point> & a) {
	/*if (a.size() == 1) return;
	sort(all(a), cmp);
	Point p1 = a[0], p2 = a.back();
	double m = (p1.x + p2.x)/2;
	pair <Point, Point> upb = up_bridge(a, m);
	pair <Point, Point> downb = down_bridge(a, m);
	vector <Point> v1, v2;
	for (int i = 0; i < sz(a); i++) {
		if (upb.X.x <= a[i].x && a[i].x <= upb.Y.x)
			continue;
		if (downb.X.x <= a[i].x && a[i].x <= downb.Y.x)
			continue;
		else {
			if (a[i].x < m)
				v1.pb(a[i]);
			if (a[i].x > m)
				v2.pb(a[i]);
		}
	}
	convex_hull_ks(v1);
	convex_hull_ks(v2);
	a.clear();
	bool found = false;
	for (int i = 0; ; i = (i + 1) % sz(v1)) {
		if (is_equal(v1[i].x, downb.X.x) && is_equal(v1[i].y, downb.X.y)) {
			found = true;
			a.pb(v1[i]);
			continue;
		}
		if (found) {
			if (is_equal(v1[i].x, upb.X.x) && is_equal(v1[i].y, upb.X.y)) {
				a.pb(v1[i]);
				break;
			}
			else
				a.pb(v1[i]);
		}
	}
	found = false;
	for (int i = 0; ; i = (i + 1) % sz(v2)) {
		if (is_equal(v2[i].x, upb.Y.x) && is_equal(v2[i].y, upb.Y.y)) {
			found = true;
			a.pb(v2[i]);
			continue;
		}
		if (found) {
			if (is_equal(v2[i].x, downb.Y.x) && is_equal(v2[i].y, downb.Y.y)) {
				a.pb(v2[i]);
				break;
			}
			else
				a.pb(v2[i]);
		}
	}*/
}

double sq_triangle(Point p1, Point p2, Point p3) {
	Point v1 = p2 - p1;
	Point v2 = p3 - p1;
	return 0.5*(det(v1.x, v1.y, v2.x, v2.y));
}

double square (vector <Point> & a) {
	double sq = 0;
	for (int i = 0; i < sz(a); i++) {
		Point p1 = i ? a[i - 1] : a.back();
		Point p2 = a[i];
		sq += (p1.x - p2.x) * (p1.y + p2.y);
	}
	return fabs(sq);
}

bool contains (Point p1, Point p2, Point p3, Point p) {
	return is_equal((fabs(sq_triangle(p1, p2, p)) + fabs(sq_triangle(p2, p3, p)) + fabs(sq_triangle(p3, p1, p))), fabs(sq_triangle(p1, p2, p3)));
}

bool on_line(Point p1, Point p2, Point p3) {
	Point v1 = p2 - p1;
	Point v2 = p3 - p1;
	return (v1.x*v2.y == v1.y*v2.x);
}

struct Line { 
	double a, b, c; 
};

Point intersect_ln (Line l1, Line l2) {
	double z = l1.a*l2.b - l1.b*l2.a;
	Point ans = Point( (l1.c*l2.b - l2.c*l1.b) / z, (l1.a*l2.c - l2.a*l1.c) / z);
	return ans;
}

Point G = Point (-10000, -10000);

Point intersect_seg (Point p1, Point p2, Point p3, Point p4) {
	Line l1, l2;
	l1.a = p2.y - p1.y;
	l1.b = p1.x - p2.x;
	l1.c = (l1.a*p1.x + l1.b*p1.y);

	l2.a = p4.y - p3.y;
	l2.b = p3.x - p4.x;
	l2.c = (l2.a*p3.x + l2.b*p3.y);

	if (l1.a*l2.b == l1.b*l2.a)
		return G;

	Point intr = intersect_ln (l1, l2);
	
	Point pp1 = Point(min(p1.x, p2.x), min(p1.y, p2.y));
	Point pp2 = Point(max(p1.x, p2.x), max(p1.y, p2.y));
	Point pp3 = Point(min(p3.x, p4.x), min(p3.y, p4.y));
	Point pp4 = Point(max(p3.x, p4.x), max(p3.y, p4.y));

	bool b = isInside(pp1, intr, pp2) && isInside(pp3, intr, pp4);
	if (b)
		return intr;
	else
		return G;
}

bool intersect_tr (Point p1, Point p2, Point p3, Point p) {
	Point zero = Point(0.0, 0.0);
	Point i1 = intersect_seg(p1, p2, zero, p);
	Point i2 = intersect_seg(p2, p3, zero, p);
	Point i3 = intersect_seg(p3, p1, zero, p);
	if (!(i1 == i2) && (!(i1 == G)) && (!(i2 == G)))
		return true;	
	if (!(i2 == i3) && (!(i2 == G)) && (!(i3 == G)))
		return true;	
	if (!(i3 == i1) && (!(i3 == G)) && (!(i1 == G)))
		return true;	
	return false;
}


double rec (Point p1, Point p2, Point p3, Point p) {
	double sq = fabs(sq_triangle(p1, p2, p3));
	if (sq < 1e-4)
		return 0.0;

	Point p4 = (p1 + p3)*0.5;
	
	if (on_line(p2, p4, p)) {	
		double add = 0;
		if (intersect_tr(p2, p4, p3, p) || intersect_tr(p1, p2, p4, p)) {
			add = 0.5*sq;
		}
		return add;
	}
	if (contains(p1, p2, p4, p)) {
		double add = 0.0;
		if (intersect_tr(p2, p4, p3, p)) {
			add = 0.5*sq;
		}
		return rec(p1, p4, p2, p) + add;
	}
	else if (contains(p2, p4, p3, p)) {
		double add = 0.0;
		if (intersect_tr(p1, p2, p4, p)) {
			add = 0.5*sq;
		}
		return rec(p2, p4, p3, p) + add;
	}

}

int main() {
#ifdef _MBCS
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif/*
	for (int i = 1; i <= 20001/3; i++) {
		cout << -i << ' ' << -i << endl;
		cout << i << ' ' << -i << endl;
		cout << 0 << ' ' << i << endl;
	}
	return 0;*/
	Point f;
	f.scan();
	printf("%.10lf", rec(Point(0.0, 0.0), Point(10.0, 0.0), Point (10.0, 10.0), f));
	return 0;
}