#include <iostream>
#include <climits>
#include <complex>
#include <algorithm>
#include <iomanip>
#include <tuple>
#include <cassert>
#include <cmath>
#include <array>
#include <random>

using namespace std;

int n;

typedef array<double, 3> V;

V pos[20];

double T(V x, V y) {
	double x1 = x[0];
	double x2 = x[1];
	double x3 = x[2];
	double y1 = y[0];
	double y2 = y[1];
	double y3 = y[2];
	return x1 * y2 + x2 * y3 + x3 * y1 - y1 * x2 - y2 * x3 - y3 * x1;
}

V P(V x, V y, V z) {
	double txy = T(x, y);
	double tyz = T(y, z);
	double tzx = T(z, x);
	
	double coef = 1.0 / sqrt(tyz * tyz + tzx * tzx + txy * txy);
	V v = {{tyz, tzx, txy}};
	v[0] *= coef;
	v[1] *= coef;
	v[2] *= coef;
	return v;
}

mt19937 rng;
double lol() {
	return uniform_real_distribution<double>(-1, 1)(rng);
}

int main() {
	cin.sync_with_stdio(false);
	
	cin >> n;
	
	double pi = atan(1) * 4;
	double coef = pi / 180;
	for(int i = 0; i < n; ++i) {
		double f, l;
		cin >> f >> l;
		f *= coef;
		l *= coef;
		pos[i][0] = cos(f) * cos(l);
		pos[i][1] = cos(f) * sin(l);
		pos[i][2] = sin(f);
	}
	
	while(n < 3) {
		pos[n++] = pos[0];
	}
	
/*	if(n == 1) {
		cout << fixed << setprecision(20) << pi << "\n";
		return 0;
	}
	if(n == 2) {
		double dx = pos[1][0] - pos[0][0];
		double dy = pos[1][1] - pos[0][1];
		double dz = pos[1][2] - pos[0][2];
		cout << fixed << setprecision(20) << pi - asin(0.5 * sqrt(dx * dx + dy * dy + dz * dz)) << "\n";
		return 0;
	}
*/	
	double req = 0.0;
	for(int i = 0; i < n; ++i) {
	for(int j = i + 1; j < n; ++j) {
	for(int k = j + 1; k < n; ++k) {
		V p;
		p[0] = lol();
		p[1] = lol();
		p[2] = lol();
		
		auto normalize = [&]() {
			double len = sqrt(p[0] * p[0] + p[1] * p[1] + p[2] * p[2]);
			p[0] /= len;
			p[1] /= len;
			p[2] /= len;
		};
		normalize();
		
		auto target = [&]() {
			double bsd = 1.0 / 0.0;
			{
				int x = i;
				double dx = p[0] - pos[x][0];
				double dy = p[1] - pos[x][1];
				double dz = p[2] - pos[x][2];
				double v = dx * dx + dy * dy + dz * dz;
				bsd = min(bsd, v);
			}
			{
				int x = j;
				double dx = p[0] - pos[x][0];
				double dy = p[1] - pos[x][1];
				double dz = p[2] - pos[x][2];
				double v = dx * dx + dy * dy + dz * dz;
				bsd = min(bsd, v);
			}
			{
				int x = k;
				double dx = p[0] - pos[x][0];
				double dy = p[1] - pos[x][1];
				double dz = p[2] - pos[x][2];
				double v = dx * dx + dy * dy + dz * dz;
				bsd = min(bsd, v);
			}
			return bsd;
		};
		
		for(double d = 0.25; d >= 1e-10; d *= 0.5) {
			for(int f = 0; f < 20; ++f) {
				double best = -1.0 / 0.0;
				V bestp;
				for(int c = 0; c < 6; ++c) {
					V old = p;
					if(c >= 3) {
						p[c % 3] += d;
					} else {
						p[c % 3] -= d;
					}
					normalize();
					double t = target();
					if(t > best) {
						best = t;
						bestp = p;
					}
					p = old;
				}
				p = bestp;
			}
		}
		
		//V p = P(pos[i], pos[j], pos[k]);
		for(int sd = 0; sd < 2; ++sd) {
			if(sd) {
				p[0] = -p[0];
				p[1] = -p[1];
				p[2] = -p[2];
			}
/*			{
				int x = i;
				double dx = p[0] - pos[x][0];
				double dy = p[1] - pos[x][1];
				double dz = p[2] - pos[x][2];
				cout << dx * dx + dy * dy + dz * dz << "\n";
			}
			{
				int x = j;
				double dx = p[0] - pos[x][0];
				double dy = p[1] - pos[x][1];
				double dz = p[2] - pos[x][2];
				cout << dx * dx + dy * dy + dz * dz << "\n";
			}
			{
				int x = k;
				double dx = p[0] - pos[x][0];
				double dy = p[1] - pos[x][1];
				double dz = p[2] - pos[x][2];
				cout << dx * dx + dy * dy + dz * dz << "\n";
			}
*/			double best = 1.0 / 0.0;
			for(int s = 0; s < n; ++s) {
				double dx = p[0] - pos[s][0];
				double dy = p[1] - pos[s][1];
				double dz = p[2] - pos[s][2];
				best = min(best, dx * dx + dy * dy + dz * dz);
			}
			req = max(req, best);
		}
	}
	}
	}
	req = sqrt(req);
	
	req = 2 * asin(req / 2);
	
	cout << fixed << setprecision(20) << req << "\n";
	
	return 0;
}
