#include <iostream>
#include <climits>
#include <complex>
#include <algorithm>
#include <iomanip>
#include <tuple>

using namespace std;

typedef complex<double> V;

int gcd(int a, int b) {
	if(b == 0) return a;
	return gcd(b, a % b);
}

int n;

struct Semiplane {
	int a;
	int b;
	int c;
	int af;
	int bf;
	double cf;
	
	V A;
	V B;
	double angle;
	
	double intT;
};
Semiplane ps[500000];

double intersectionParam(V a, V b, V c, V d) {
	V u = (c - a) / (b - a);
	V v = (d - a) / (b - a);
	return (u.real() * v.imag() - u.imag() * v.real()) / (v.imag() - u.imag());
}

int main() {
	cin.sync_with_stdio(false);
	
	cin >> n;
	for(int i = 0; i < n; ++i) {
		Semiplane& p = ps[i];
		cin >> p.a >> p.b >> p.c;
		int d = gcd(abs(p.a), abs(p.b));
		p.af = p.a / d;
		p.bf = p.b / d;
		p.cf = (double)p.c / (double)d;
	}
	
	auto cmp = [](const Semiplane& x, const Semiplane& y) {
		return make_tuple(x.af, x.bf, x.cf) < make_tuple(y.af, y.bf, y.cf);
	};
	auto eq = [](const Semiplane& x, const Semiplane& y) {
		return make_tuple(x.af, x.bf) == make_tuple(y.af, y.bf);
	};
	sort(ps, ps + n, cmp);
	n = unique(ps, ps + n, eq) - ps;
	
	for(int i = 0; i < n; ++i) {
		Semiplane& p = ps[i];
		double coef = (double)p.c / ((double)p.a * (double)p.a + (double)p.b * (double)p.b);
		p.A = V(p.a, p.b);
		p.A *= coef;
		p.B = V(0, 1) * V(p.a, p.b);
		p.angle = atan2(p.B.imag(), p.B.real());
		p.B += p.A;
	}
	
	sort(ps, ps + n, [](const Semiplane& x, const Semiplane& y) {
		return x.angle < y.angle;
	});
	
	if(n <= 1) {
		cout << -1 << "\n";
		return 0;
	}
	
	vector<int> hull;
	hull.push_back(n - 1);
	ps[n - 1].intT = -1.0 / 0.0;
	for(int i = 0; i < n; ++i) {
		while(true) {
			int prev = hull.back();
			int cross = ps[prev].a * ps[i].b - ps[prev].b * ps[i].a;
			if(cross < 0) {
				cout << -1 << "\n";
				return 0;
			}
			if(cross == 0) {
				double maxc = ps[i].cf;
				double minc = -ps[prev].cf;
				if(minc < maxc) {
					cout << -1 << "\n";
					return 0;
				} else {
					cout << 0 << "\n";
					return 0;
				}
			}
			
			double intT = intersectionParam(ps[prev].A, ps[prev].B, ps[i].A, ps[i].B);
			if(intT < ps[prev].intT) {
				 hull.pop_back();
			} else {
				ps[i].intT = intersectionParam(ps[i].A, ps[i].B, ps[prev].A, ps[prev].B);
				hull.push_back(i);
				break;
			}
		}
	}
	
	vector<V> asdfa;
	for(int i : hull) {
		asdfa.push_back((1 - ps[i].intT) * ps[i].A + ps[i].intT * ps[i].B);
	}
	
	double ret = 0.0;
	for(int i = 1; i < asdfa.size(); ++i) {
		ret += asdfa[i - 1].real() * asdfa[i].imag() - asdfa[i].real() * asdfa[i - 1].imag();
	}
	ret *= 0.5;
	ret = abs(ret);
	
	cout << fixed << setprecision(20) << ret << "\n";
	
	return 0;
}
