#include <iostream>
#include <cstdio>
#include <cassert>
#include <vector>
#include <algorithm>
#include <memory.h>
#include <cassert>
#include <math.h>

using namespace std;

typedef long long ll;

const int maxn = 128;
const int maxm = 16;
const double eps = 1e-9;

struct pt {
	double x, y;

	pt() {}
	pt(double x, double y) : x(x), y(y) {}

	double operator* (const pt &p) {
		return x * p.y - p.x * y;
	}
};


struct line {
	double a, b, c;

	line() {}
	line(double a, double b, double c) : a(a), b(b), c(c) {}

	bool operator< (const line &l) const {
		pt n1 = pt(a, b);
		pt n2 = pt(l.a, l.b);
		double x = n1 * n2;
		if (fabs(x) < eps) return c < l.c;
		return x < 0;
	}

	bool operator== (const line &l) const {
		pt n1 = pt(a, b);
		pt n2 = pt(l.a, l.b);
		double x = n1 * n2;
		if (fabs(x) < eps) return 1;
		return 0;
	}

	double getY(double x) {
		return (c - a * x) / b;
	}
};

vector<line> up, down;
double startx, lastx;

void add(double a, double b, double c) {
	if (fabs(b) < eps) {
		if (a > 0) {
			lastx = min(lastx, c / a);
		} else {
			startx = max(startx, c / a);
		}
		return;
	}
	if (b > 0 || b == 0 && a > 0) up.push_back(line(a, b, c));
	else if (b < 0 || b == 0 && a < 0) down.push_back(line(a, -b, c));
	else assert(0);
}

pt intersect(line l1, line l2) {
	double det = l1.a * l2.b - l2.a * l1.b;
	assert(fabs(det) > eps);
	double detx= l1.c * l2.b - l2.c * l1.b;
	double dety= l1.a * l2.c - l2.a * l1.c;
	return pt(detx / det, dety / det);
}

vector<pt> build(vector<line> &v) {
	sort(v.begin(), v.end());
	vector<line> nv;
	for (int i = 0; i < (int)v.size(); i++) {
		int j = i + 1;
		while (j < (int)v.size() && v[i] == v[j]) j++;
		nv.push_back(v[i]);
		i = j - 1;
	}
	swap(v, nv);

	vector<line> res;
	vector<pt> x;
	res.push_back(v[0]);
	x.push_back(pt(-1e100, v[0].getY(-1e100)));
	for (int i = 1; i < (int)v.size(); i++) {
		pt cx = intersect(v[i], res.back());
		assert(cx.x > -1e100);
		while (cx.x <= x.back().x) {
			x.pop_back();
			res.pop_back();
			cx = intersect(v[i], res.back());
			assert(cx.x > -1e100);
		}
		x.push_back(cx);
		res.push_back(v[i]);
	}
	x.push_back(pt(1e100, res.back().getY(1e100)));
	v = res;
	return x;
}

double get(pt A, pt B, double x) {
	return A.y + (B.y - A.y) * (x - A.x) / (B.x - A.x);
}

int main() {
	freopen("job.in", "r", stdin);

	int n;
	while (cin >> n) {
		up.clear();
		down.clear();
		startx = -1e30;
		lastx = 1e30;
		for (int i = 0; i < n; i++) {
			int a, b, c;
			cin >> a >> b >> c;
			add(a, b, c);
		}
		add(1, 0, 1e30);
		add(-1, 0, 1e30);
		add(0, 1, 1e30);
		add(0, -1, 1e30);

		vector<pt> vup = build(up);
		vector<pt> vdown = build(down);
		for (int i = 0; i < (int)vdown.size(); i++) vdown[i].y *= -1;
		for (int i = 0; i < (int)down.size(); i++) down[i].b *= -1;

		double s = 0;
		int iup = 0, idown = 0;
		bool flag = 0;
		while (1) {
			double lx = max(vup[iup].x, vdown[idown].x);
			if (lx >= lastx) break;
			double rx;
			/*if (max(vup[iup].x, vdown[idown].x) - lx > eps) {
				rx = max(vup[iup].x, vdown[idown].x);
			} else {
				rx = min(vup[iup + 1].x, vdown[idown + 1].x);
			}*/
			rx = min(vup[iup + 1].x, vdown[idown + 1].x);

			double ox = rx;

			if (lx < startx) lx = startx;
			if (rx > lastx) rx = lastx;

			if (up[iup].getY(lx) < down[idown].getY(lx)) {
				pt p = intersect(up[iup], down[idown]);
				lx = max(lx, p.x);
			}

			if (up[iup].getY(rx) < down[idown].getY(rx)) {
				pt p = intersect(up[iup], down[idown]);
				rx = min(rx, p.x);				
			}

			if (lx < rx) {
				double mx = (lx + rx) / 2.0;
				if (up[iup].getY(mx) > down[idown].getY(mx)) {
					double yul = up[iup].getY(lx);
					double yur = up[iup].getY(rx);
					double ydl = down[idown].getY(lx);
					double ydr = down[idown].getY(rx);
					s += (rx - lx) * (yul - ydl + yur - ydr) / 2.0;
				}
			}
			iup += fabs(vup[iup + 1].x - ox) < eps;
			idown += fabs(vdown[idown + 1].x - ox) < eps;
		}
		if (s > 1e20) cout << -1 << endl;
		else printf("%.10lf\n", s);
	}

	return 0;
}