#if 1
#include <cmath>
#include <iostream>
#include <vector>
#include <cstdio>
using namespace std;

const double eps = 1e-9;

bool doubleEqual(double a, double b)
{
	return fabs(a - b) < eps;
}
bool doubleLessOrEqual(double a, double b)
{
	return a < b || doubleEqual(a, b);
}

struct Point 
{
	double x, y;
	Point() {}
	Point(double x, double y) : x(x), y(y) {}
	friend bool operator < (const Point &a, const Point &b)
	{
		return make_pair(a.x, a.y) < make_pair(b.x, b.y);
	}
	void scan()
	{
		scanf("%lf%lf", &x, &y);
	}
	Point operator - (const Point &p) const
	{
		return Point(x - p.x, y - p.y);
	}
	Point operator + (const Point &p) const
	{
		return Point(x + p.x, y + p.y);
	}
	Point operator * (double k) const
	{
		return Point(x * k, y * k);
	}
	double operator * (const Point &p) const
	{
		return y * p.x - x * p.y;
	}
	bool operator == (const Point &p) const
	{
		return doubleEqual(x, p.x) && doubleEqual(y, p.y);
	}
};

double area(Point &a, Point &b, Point &c)
{
	double r = (a.x - c.x) * (b.y - c.y) - (a.y - c.y) * (b.x - c.x);
	if(doubleEqual(r, 0)) return 0;
	return r;
}

bool intersectSegments(Point &a, Point &b, Point &c, Point &d)
{
	Point v = b - a;
	double s1 = (c - a) * (d - a);
	double s2 = (d - b) * (c - b);
	double s = s1 + s2;

	if(doubleEqual(s, 0)) return false;

	v = v * (s1 / s);
	Point O = a + v;

	Point bounda(min(a.x, b.x), min(a.y, b.y));
	Point boundb(max(a.x, b.x), max(a.y, b.y));

	if(!doubleLessOrEqual(bounda.x, O.x)) return false;
	if(!doubleLessOrEqual(bounda.y, O.y)) return false;
	if(!doubleLessOrEqual(O.x, boundb.x)) return false;
	if(!doubleLessOrEqual(O.y, boundb.y)) return false;

	Point boundc(min(c.x, d.x), min(c.y, d.y));
	Point boundd(max(c.x, d.x), max(c.y, d.y));

	if(!doubleLessOrEqual(boundc.x, O.x)) return false;
	if(!doubleLessOrEqual(boundc.y, O.y)) return false;
	if(!doubleLessOrEqual(O.x, boundd.x)) return false;
	if(!doubleLessOrEqual(O.y, boundd.y)) return false;

	return true;
}

int main()
{
#ifdef _DEBUG
	freopen("input.txt", "r", stdin);
#endif
	Point f;
	f.scan();
	Point ra = Point(0,0);
	Point a = Point(0, 0), b = Point(10, 0), c = Point(10, 10);
	double answer = 0;
	while(true)
	{
		Point newb = Point((a.x + c.x) / 2, (a.y + c.y) / 2);
		if(doubleEqual(area(a, b, f), 0)) break;
		if(doubleEqual(area(b, c, f), 0)) break;
		if(doubleEqual(area(b, a, f), 0)) break;

		if(fabs(area(a, b, c)) < eps) break;
		
		int count = 0;
		if(doubleEqual(area(b, newb, f) * area(b, newb, c), 0))
		{
			answer += fabs(area(newb, b, c));
			break;
		}
		else if(area(b, newb, f) * area(b, newb, c) > 0)
		{
			if(intersectSegments(ra, f, b, newb)) count++;
			if(intersectSegments(ra, f, a, newb)) count++;
			if(intersectSegments(ra, f, a, b)) count++;
			if(a == ra) count--;
			if(b == ra) count--;
			if(c == ra) count--;
			a = c;
			c = b;
			b = newb;
		}
		else if(area(b, newb, f) * area(b, newb, c) < 0)
		{
			if(intersectSegments(ra, f, b, newb)) count++;
			if(intersectSegments(ra, f, c, newb)) count++;
			if(intersectSegments(ra, f, c, b)) count++;
			if(a == ra) count--;
			if(b == ra) count--;
			if(c == ra) count--;
			c = a;
			a = b;
			b = newb;
		}
		if(count == 2)
		{
			answer += fabs(area(a, b, c));
		}
		//fprintf(stderr, "{%.5lf,%.5lf} {%.5lf,%.5lf} {%.5lf,%.5lf}\n", a.x, a.y, b.x, b.y, c.x, c.y); 
	}
	printf("%.10lf", answer / 2);
}

#endif 